Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1976)

Unified Diff: device/bluetooth/bluetooth_low_energy_peripheral_delegate.h

Issue 1948763003: Adding support for service scan on OS X (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@cleanup
Patch Set: Adding disconnect with error Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/bluetooth_low_energy_peripheral_delegate.h
diff --git a/device/bluetooth/bluetooth_low_energy_central_manager_delegate.h b/device/bluetooth/bluetooth_low_energy_peripheral_delegate.h
similarity index 53%
copy from device/bluetooth/bluetooth_low_energy_central_manager_delegate.h
copy to device/bluetooth/bluetooth_low_energy_peripheral_delegate.h
index 03460bf831eaba96b48b12fe411bdb8c021ce771..93db50fa0d6526252c58bfd5479a54434da9cd7b 100644
--- a/device/bluetooth/bluetooth_low_energy_central_manager_delegate.h
+++ b/device/bluetooth/bluetooth_low_energy_peripheral_delegate.h
@@ -5,9 +5,8 @@
#ifndef DEVICE_BLUETOOTH_BLUETOOTH_LOW_ENERGY_CENTRAL_MANAGER_DELEGATE_H_
ortuno 2016/05/06 16:03:33 nit: Wrong ifndef
jlebel 2016/05/07 00:16:11 Done.
#define DEVICE_BLUETOOTH_BLUETOOTH_LOW_ENERGY_CENTRAL_MANAGER_DELEGATE_H_
-#include <memory>
-
#include "base/mac/sdk_forward_declarations.h"
+#include "base/memory/ref_counted.h"
#include "build/build_config.h"
#if defined(OS_IOS)
@@ -18,21 +17,19 @@
namespace device {
-class BluetoothAdapterMac;
-class BluetoothLowEnergyCentralManagerBridge;
-class BluetoothLowEnergyDiscoveryManagerMac;
+class BluetoothLowEnergyDeviceMac;
+class BluetoothLowEnergyPeripheralBridge;
} // namespace device
-// This class will serve as the Objective-C delegate of CBCentralManager.
-@interface BluetoothLowEnergyCentralManagerDelegate
- : NSObject<CBCentralManagerDelegate> {
- std::unique_ptr<device::BluetoothLowEnergyCentralManagerBridge> bridge_;
+// This class will serve as the Objective-C delegate of CBPeripheral.
+@interface BluetoothLowEnergyPeripheralDelegate
+ : NSObject<CBPeripheralDelegate> {
+ std::unique_ptr<device::BluetoothLowEnergyPeripheralBridge> bridge_;
}
-- (id)initWithDiscoveryManager:
- (device::BluetoothLowEnergyDiscoveryManagerMac*)discovery_manager
- andAdapter:(device::BluetoothAdapterMac*)adapter;
+- (id)initWithBluetoothLowEnergyDeviceMac:
+ (device::BluetoothLowEnergyDeviceMac*)device_mac;
@end

Powered by Google App Engine
This is Rietveld 408576698